@@ -30,6 +30,18 @@ qx.Class.define("callbackery.ui.Popup", {
             centerOnContainerResize: true,
             centerOnAppear: true
         });
+        let appRoot = this.getApplicationRoot();
+        let bounds = appRoot.getBounds();
+        
+        // make sure the window does not get larger than the screen by default ... 
+        if (bounds) {
+            if (!this.getMaxWidth()) {
+                this.setMaxWidth(bounds.width-20);
+            }
+            if (!this.getMaxHeight()) {
+                this.setMaxHeight(bounds.height-20);
+            }
+        }
 
         if (cfg.set){
             this.set(cfg.set);
